@@ -28,6 +28,6 @@ test_that("raises error when dfm is empty (#1419)",  {
 
     mx <- quanteda::dfm_trim(data_dfm_lbgexample, 1000)
     expect_error(textmodel_affinity(mx, y = c(-1, NA, NA, NA, 1, NA)),
-                 quanteda:::message_error("dfm_empty"))
+                 quanteda.textmodels:::message_error("dfm_empty"))
 
 })
